summaryrefslogtreecommitdiffstats
path: root/api/examples/glfsxmp.c
diff options
context:
space:
mode:
Diffstat (limited to 'api/examples/glfsxmp.c')
-rw-r--r--api/examples/glfsxmp.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/api/examples/glfsxmp.c b/api/examples/glfsxmp.c
index 600d72fb5..7180a997f 100644
--- a/api/examples/glfsxmp.c
+++ b/api/examples/glfsxmp.c
@@ -293,19 +293,19 @@ test_h_unlink (void)
goto out;
}
/* unlink non-existant regular file */
ret = glfs_h_unlink (fs, dir, my_file);
if ((ret && errno != ENOENT) || (ret == 0)) {
- fprintf (stderr, "glfs_h_unlink: error unlinking non-existant %s: invalid errno ,%d, %s\n",
+ fprintf (stderr, "glfs_h_unlink: error unlinking non-existent %s: invalid errno ,%d, %s\n",
my_file, ret, strerror (errno));
printf ("glfs_h_unlink tests: FAILED\n");
goto out;
}
- /* unlink non-existant directory */
+ /* unlink non-existent directory */
ret = glfs_h_unlink (fs, dir, my_subdir);
if ((ret && errno != ENOENT) || (ret == 0)) {
- fprintf (stderr, "glfs_h_unlink: error unlinking non-existant %s: invalid errno ,%d, %s\n",
+ fprintf (stderr, "glfs_h_unlink: error unlinking non-existent %s: invalid errno ,%d, %s\n",
my_subdir, ret, strerror (errno));
printf ("glfs_h_unlink tests: FAILED\n");
goto out;
@@ -293,19 +293,19 @@ test_h_unlink (void)
goto out;
}
- /* unlink non-existant regular file */
+ /* unlink non-existent regular file */
ret = glfs_h_unlink (fs, dir, my_file);
if ((ret && errno != ENOENT) || (ret == 0)) {